(function(){

var requiredInputsSelector = '.product-sku-option, .product-sku-customization[data-required=true]';
var skuChangingInputsSelector = '.product-sku-option';
var productFormSelector = 'form[data-product-id]';

$(document).ready(function(){
  $('body').on('change', requiredInputsSelector, changedProductSkuOption);
  $('body').on('ajax:before', productFormSelector, beforeProductAddToCart);
  $('body').on('ajax:success', productFormSelector, addedProductToCart);
  $('body').on('ajax:error', productFormSelector, addToCartError);
});

// - Events

/*
* Update the form state and check for a sku any time options change
*/
var changedProductSkuOption = function(e){
  var $form = $(this).parents('form');

  var valid = checkFormValidation($form, true);
  updateFormWithValidation($form, valid);

  if(valid){
    var id = $form.data('productId');
    $.ajax('/store/api/products/' + id + '/skus', {
      data: {
        options: extractOptionIdsFromForm($form)
      },
      success: function(skus){
        updateFormWithSkuData($form, skus);
      }
    });
  }
};

/*
* Return true if all required fields are filled out
*/
var checkFormValidation = function($form, only_sku_changes){
  var valid = true;
  var inputs = null;
  if (only_sku_changes) {
    inputs = $form.find(skuChangingInputsSelector);
  } else {
    inputs = $form.find(requiredInputsSelector);
  }
  var len = inputs.length;
  for(var i=0; i<len; i++) {
    var input = $(inputs[i]);
    if(input.val() === ''){
      valid = false;
      break;
    }
  }
  return valid;
};

/*
* Take in a form element and return an array of selected option ids
*/
var extractOptionIdsFromForm = function($form){
  var options = [];
  var inputs = $form.find('.product-sku-option');
  var len = inputs.length;
  for(var i=0; i<len; i++){
    var value = $(inputs[i]).val();
    options.push(value);
  }
  return options;
};

/*
* Set request mode to JSON (instead of default JS)
*/
var beforeProductAddToCart = function(xhr, settings){
  $(this).data('type', 'json');
};

/*
* On successfully adding a product to your cart
*/
var addedProductToCart = function(event, json, textStatus, jqXHR){
  $(this).trigger('tb_commerce:cart:added', json);
};

/*
* On receiving an error while trying to add a product to your cart
*/
var addToCartError = function(event){
  $(this).trigger('tb_commerce:cart:error', arguments);
};

// - View

/*
* Enable or disable the submit button based on validation status
*/
var updateFormWithValidation = function($form, valid){
  var submitButton = $form.find('input[type=submit]');
  if(valid){
    submitButton.attr('disabled', false);
  }
  else{
    submitButton.attr('disabled', true);
  }
};

/*
* Populate the item_id hidden input, or disable the submit button
*/
var updateFormWithSkuData = function($form, skus){
  var skuInput = $form.find('#tb_commerce_cart_item_tb_commerce_product_sku_id');
  var submitButton = $form.find('input[type=submit]');
  var infoText = $form.find('.product-add-to-cart-info-text');

  if(skus.length > 0){
    var sku = skus[0];
    skuInput.val(sku.id);
    submitButton.attr('disabled', false);
    $form.trigger('tb_commerce:sku:loaded', sku);
  }
  else{
    skuInput.val('');
    submitButton.attr('disabled', true);
    $form.trigger('tb_commerce:sku:notfound');
  }
};

})();
