require "tb_core"
require "tb_commerce/configuration"
require "jbuilder"
require "paperclip"
require "stripe"
require 'countries'
require 'country_select'

module TbCommerce
  class Engine < ::Rails::Engine
    # isolate_namespace TbCommerce
    engine_name 'tb_commerce'

    config.autoload_paths += Dir["#{config.root}/lib/**/"]

    initializer 'tb_commerce.cart_helpers' do |config|
      ActiveSupport.on_load :spud_application_controller do
        Spud::ApplicationController.send :include, TbCommerce::ControllerHelpers
      end
    end

    initializer 'tb_commerce.admin', :before => 'tb_core.admin' do |config|
      Spud::Core.admin_applications += [
        #{:name => 'Products', :url => '/admin/products' },
        {:name => 'Orders', :thumbnail => "tb_commerce/orders.png", :url => '/admin/orders', :badge => ->(user){
          TbCommerce::Order.where(:status => 'placed').count
        }},
        {:name => 'Transactions', :thumbnail => "tb_commerce/transactions.png", :url => '/admin/transactions'}
      ]
    end

    config.generators do |g|
      g.test_framework :rspec, :fixture => false
      g.fixture_replacement :factory_girl, :dir => 'spec/factories'
      g.assets false
      g.helper true
    end

  end
end
